import { AccountInfo, MintInfo } from "@solana/spl-token";
import BN from "bn.js";
export interface ITransitionFee {
    percentage: number;
    interval: number;
}
export declare type ExponentialCurveV0 = {
    c: BN;
    b: BN;
    pow: number;
    frac: number;
};
export declare function fromCurve(curve: any, baseStorage: AccountInfo, baseMint: MintInfo, targetMint: MintInfo, goLiveUnixTime: number): IPricingCurve;
export interface IPricingCurve {
    current(unixTime?: number): number;
    locked(): number;
    sellTargetAmount(targetAmountNum: number, baseRoyaltiesPercent: number, targetRoyaltiesPercent: number, unixTime?: number): number;
    buyTargetAmount(targetAmountNum: number, baseRoyaltiesPercent: number, targetRoyaltiesPercent: number, unixTime?: number): number;
    buyWithBaseAmount(baseAmountNum: number, baseRoyaltiesPercent: number, targetRoyaltiesPercent: number, unixTime?: number): number;
    buyWithBaseRootEstimates(baseAmountNum: number, baseRoyaltiesPercent: number, unixTime?: number): number[];
    buyTargetAmountRootEstimates(targetAmountNum: number, targetRoyaltiesPercent: number, unixTime?: number): number[];
}
declare type TimeCurveArgs = {
    curve: any;
    baseStorage: AccountInfo;
    baseMint: MintInfo;
    targetMint: MintInfo;
    goLiveUnixTime: number;
};
interface ITimeCurveItem {
    subCurve: IPricingCurve;
    offset: number;
    buyTransitionFees: ITransitionFee | null;
    sellTransitionFees: ITransitionFee | null;
}
export declare class TimeCurve implements IPricingCurve {
    curve: any;
    baseStorage: AccountInfo;
    baseMint: MintInfo;
    targetMint: MintInfo;
    goLiveUnixTime: number;
    constructor({ curve, baseStorage, baseMint, targetMint, goLiveUnixTime }: TimeCurveArgs);
    currentCurve(unixTime?: number): ITimeCurveItem;
    current(unixTime?: number): number;
    locked(): number;
    sellTargetAmount(targetAmountNum: number, baseRoyaltiesPercent: number, targetRoyaltiesPercent: number, unixTime?: number): number;
    buyTargetAmount(targetAmountNum: number, baseRoyaltiesPercent: number, targetRoyaltiesPercent: number, unixTime?: number): number;
    buyWithBaseAmount(baseAmountNum: number, baseRoyaltiesPercent: number, targetRoyaltiesPercent: number, unixTime?: number): number;
    buyWithBaseRootEstimates(baseAmountNum: number, baseRoyaltiesPercent: number, unixTime?: number): number[];
    buyTargetAmountRootEstimates(targetAmountNum: number, targetRoyaltiesPercent: number, unixTime?: number): number[];
}
export declare class ExponentialCurve implements IPricingCurve {
    c: number;
    b: number;
    k: number;
    pow: number;
    frac: number;
    baseStorage: AccountInfo;
    baseMint: MintInfo;
    targetMint: MintInfo;
    constructor(curve: ExponentialCurveV0, baseStorage: AccountInfo, baseMint: MintInfo, targetMint: MintInfo);
    buyWithBaseRootEstimates(baseAmountNum: number, baseRoyaltiesPercent: number): number[];
    buyTargetAmountRootEstimates(targetAmountNum: number, targetRoyaltiesPercent: number): number[];
    current(): number;
    locked(): number;
    changeInTargetAmount(targetAmountNum: number, baseRoyaltiesPercent: number, targetRoyaltiesPercent: number): number;
    sellTargetAmount(targetAmountNum: number, baseRoyaltiesPercent: number, targetRoyaltiesPercent: number): number;
    buyTargetAmount(targetAmountNum: number, baseRoyaltiesPercent: number, targetRoyaltiesPercent: number): number;
    buyWithBaseAmount(baseAmountNum: number, baseRoyaltiesPercent: number, targetRoyaltiesPercent: number): number;
}
export {};
//# sourceMappingURL=curves.d.ts.map